@@ -143,7 +143,7 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
 
         dataframe['time'] = pd.to_datetime(dataframe['time'], unit='s')
         dataframe = dataframe.sort_values(by=['time'])
-        dataframe = dataframe.rename(columns={"time": "date"}, errors="raise")
+        dataframe = dataframe.rename(columns={"time": "date", 'volumeto':'volume'}, errors="raise")
         dataframe = dataframe.set_index(dataframe['date'])
         dataframe = dataframe.drop(columns=['date'])
         print('size fetched')
@@ -160,12 +160,66 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
     return dataframe
 
 
-def get_npx_hitbtc_bindex_spread():
+def get_npx_hitbtc_bindex_spread(depth = 1):
     hbid, hask = fetch_rest_hitbtc_orderbook()
     bbid, bask = fetch_rest_bindex_orderbook()
     bnb = fetch_rest_crypto_compare_last_minute_ohlc('BNB','USDT')
     eth = fetch_rest_crypto_compare_last_minute_ohlc('ETH','USDT')
-    return hbid, hask, bbid, bask, eth
+
+    hbid = hbid.iloc[:depth]
+    hask = hask.iloc[:depth]
+    results = {}
+    if depth>1:
+
+        hbid['price_size'] = hbid['price'].astype(float) * hbid['size'].astype(float)
+        hask['price_size'] = hask['price'].astype(float) * hask['size'].astype(float)
+
+        bbid['price_size'] = bbid['price'].astype(float) * bbid['size'].astype(float)
+        bask['price_size'] = bask['price'].astype(float) * bask['size'].astype(float)
+
+        results['hitbtc_bid_price'] = float(hbid['price_size'].astype(float).sum()/hbid['size'].astype(float).sum())
+        results['bindex_bid_price'] = float(bbid['price_size'].astype(float).sum()/bbid['size'].astype(float).sum())
+        results['hitbtc_ask_price'] = float(hask['price_size'].astype(float).sum()/hask['size'].astype(float).sum())
+        results['bindex_ask_price'] = float(bask['price_size'].astype(float).sum()/bask['size'].astype(float).sum())
+
+        results['eth_price'] = float(eth['close'])
+        results['bnb_price'] = float(bnb['close'])
+
+
+        results['hitbtc_bid_size'] = float(hbid['size'].astype(float).sum())
+        results['bindex_bid_size'] = float(bbid['size'].astype(float).sum())
+        results['hitbtc_ask_size'] = float(hask['size'].astype(float).sum())
+        results['bindex_ask_size'] = float(bask['size'].astype(float).sum())
+
+
+        results['converted_hitbtc_bid_price'] = results['hitbtc_bid_price'] * results['eth_price']
+        results['converted_bindex_bid_price'] = results['bindex_bid_price'] * results['bnb_price']
+        results['converted_hitbtc_ask_price'] = results['hitbtc_ask_price'] * results['eth_price']
+        results['converted_bindex_ask_price'] = results['bindex_ask_price'] * results['bnb_price']
+
+
+
+    else :
+        results['hitbtc_bid_price'] = float(hbid['price'][0])
+        results['bindex_bid_price'] = float(bbid['price'][0])
+        results['hitbtc_ask_price'] = float(hask['price'][0])
+        results['bindex_ask_price'] = float(bask['price'][0])
+
+        results['eth_price'] = float(eth['close'])
+        results['bnb_price'] = float(bnb['close'])
+
+        results['hitbtc_bid_size'] = float(hbid['size'][0])
+        results['bindex_bid_size'] = float(bbid['size'][0])
+        results['hitbtc_ask_size'] = float(hask['size'][0])
+        results['bindex_ask_size'] = float(bask['size'][0])
+
+
+        results['converted_hitbtc_bid_price'] = results['hitbtc_bid_price'] * results['eth_price']
+        results['converted_bindex_bid_price'] = results['bindex_bid_price'] * results['bnb_price']
+        results['converted_hitbtc_ask_price'] = results['hitbtc_ask_price'] * results['eth_price']
+        results['converted_bindex_ask_price'] = results['bindex_ask_price'] * results['bnb_price']
+
+    return pd.DataFrame(data = results, index =[datetime.datetime.now()])
 
 
 def fetch_rest_hitbtc_orderbook():
@@ -296,23 +350,18 @@ def fetch_crypto_minutely_data(ssj=None, local_root_directory=None, minutely_ret
 
 def fetch_local_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_pkl_filename_suffix='_hourly_returns.pkl',refetch_all=True, daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None, ssj_against='USDT', exchange = 'binance',local_path= f'/Users/stefanduprey/Documents/My_StephaneStrategy/'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
-
     pickle_saving_path = local_root_directory + ssj + '_' + dates_stub + hourly_return_pkl_filename_suffix
-
     if ssj == 'BTC':
         dataframe = pd.read_pickle(local_path + f'btc_hourly.pkl')
-
     elif ssj == 'ETH':
         dataframe = pd.read_pickle(local_path + f'eth_hourly.pkl')
 
     dataframe.columns =  ['date','close']
-
     dataframe['date'] = pd.to_datetime(dataframe['date'])
     dataframe = dataframe.set_index(dataframe['date'])
     dataframe = dataframe.drop(columns=['date'])
     dataframe = dataframe.sort_index()
     dataframe['open'] = dataframe['close'].shift(1)
-
     print('size fetched')
     print(dataframe.shape)
     dataframe = dataframe[dataframe.index >= daily_crypto_starting_day]
@@ -357,6 +406,7 @@ def fetch_crypto_hourly_data(ssj=None, local_root_directory=None, hourly_return_
         dataframe = None
         for me_timestamp in [ts18, ts17, ts16, ts15, ts14, ts13, ts12, ts11, ts10, ts9, ts8, ts7, ts6, ts5, ts4, ts3, ts2, ts1, ts]:
             print('waiting')
+            time.sleep(1)
             df = request_hour_data_paquet(hours_url_request, me_timestamp, ssj)
             if df is not None:
                 if dataframe is not None:
