@@ -113,7 +113,7 @@ def plot_multiple_time_series(data_df, split =False, logy = True, title = 'Strat
 #    palette = cycle(px.colors.qualitative.Vivid)
 #    palette = cycle(px.colors.qualitative.Safe)
 #    data_df[~data_df.isin([np.nan, np.inf, -np.inf]).any(1)] = 0.
-    if drop_na_inf:
+    if drop_na_inf and not data_df.isin([np.nan, np.inf, -np.inf]).astype(int).sum(axis=0).sum(axis=0) == 0:
         data_df.iloc[data_df.isin([np.nan, np.inf, -np.inf]).values] = 0.
     if split:
         fig = make_subplots(rows=1, cols=len(data_df.columns))
@@ -183,6 +183,17 @@ def plot_multiple_turnover(data_df, ma = None):
     fig.update_xaxes(rangeslider_visible=True)
     return fig
 
+def plot_drawdown(data_df, column_name):
+    fig = make_subplots(rows=1, cols=1)
+    trace_sig = go.Scatter(
+        x=data_df.index,
+        y=data_df[column_name],
+        name="drawdown",
+        opacity=0.8)
+    fig.append_trace(trace_sig, row=1, col=1)
+    fig.update_layout(height=600, width=1600, title_text="Drawdown chart",showlegend=True)
+    fig.update_xaxes(rangeslider_visible=True)
+    return fig
 
 def plot_correlation(data_df):
     static_correlation_df = data_df.corr()
