@@ -677,7 +677,7 @@ def fetch_all_necessary_data_b40(public_key = None, private_key= None, start_tim
     ############  ########### converting trades commission
     trades['ts'] = pd.to_datetime(trades['ts'])
     def round_to_the_minute(row):
-        new_date = datetime.datetime(year=row['ts'].year, month = row['ts'].month, day =row['ts'].day, minute= row['ts'].minute)
+        new_date = datetime.datetime(year=row['ts'].year, month = row['ts'].month, day =row['ts'].day, hour =row['ts'].hour, minute= row['ts'].minute)
         return new_date
     trades['min_ts'] = trades.apply(round_to_the_minute,axis=1)
     trades = pd.merge(trades, ohlc_bnb_min_binance[['open']],left_on='min_ts',right_index=True)
